import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const web = [
  {
    path: '/',
    redirect: '/adminCenter/homeIndex',
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '管理登录' },
    component: () => import('../views/login.vue'),
  },
  {
    path: '/register',
    name: 'register',
    meta: { title: '用户注册' },
    component: () => import('../views/register.vue'),
  },
  {
    path: '/adminCenter/homeIndex',
    name: 'adminCenter',
    component: () => import('@common/src/components/admin-frame/Home.vue'),
    children: [
      {
        path: '/adminCenter/homeIndex',
        name: 'admin_homeIndex',
        meta: { title: '首页' },
        component: () => import('../views/adminCenter/homeIndex/index.vue'),
      },
      // 平台用户
      {
        path: '/user/basic',
        meta: { title: '基本信息' },
        component: () => import('../views/user/basic/index.vue'),
      },
      {
        path: '/user/basic/expertDetail',
        meta: { title: '专家信息管理' },
        component: () => import('../views/user/basic/expertDetail.vue'),
      },
      {
        path: '/user/message',
        meta: { title: '消息管理' },
        component: () => import('../views/user/message/index.vue'),
      },
      {
        path: '/user/product',
        meta: { title: '信息发布' },
        component: () => import('../views/user/product/index.vue'),
      },
      {
        path: '/user/product/detail',
        meta: { title: '信息管理' },
        component: () => import('../views/user/product/detail.vue'),
      },
      {
        path: '/user/product/info',
        meta: { title: '详细信息' },
        component: () => import('../views/user/product/info.vue'),
      },
      // {
      //   path: '/user/product/stay',
      //   meta: { title: '待发布' },
      //   component: () => import('../views/user/product/stay/index.vue'),
      // },
      // {
      //   path: '/user/product/examine',
      //   meta: { title: '审核中' },
      //   component: () => import('../views/user/product/examine/index.vue'),
      // },
      // {
      //   path: '/user/product/already',
      //   meta: { title: '已发布' },
      //   component: () => import('../views/user/product/already/index.vue'),
      // },
      // {
      //   path: '/user/product/fail',
      //   meta: { title: '审核拒绝' },
      //   component: () => import('../views/user/product/fail/index.vue'),
      // },
      // {
      //   path: '/user/product/data',
      //   meta: { title: '信息管理' },
      //   component: () => import('../views/user/product/data/index.vue'),
      // },
      // {
      //   path: '/user/product/data/info',
      //   meta: { title: '详细信息' },
      //   component: () => import('../views/user/product/data/info.vue'),
      // },
      {
        path: '/user/live/next',
        meta: { title: '下期直播' },
        component: () => import('../views/user/live/next.vue'),
      },
      {
        path: '/user/live/past',
        meta: { title: '已往直播' },
        component: () => import('../views/user/live/past.vue'),
      },
      {
        path: '/user/matter',
        meta: { title: '事项管理' },
        component: () => import('../views/user/matter/index.vue'),
      },
      {
        path: '/user/uppasswd',
        meta: { title: '修改密码' },
        component: () => import('../views/user/uppasswd/index.vue'),
      },
      // 科技成果
      // achieveUser
      {
        path: '/achieveUser/basic',
        meta: { title: '展会基本信息' },
        component: () => import('../views/achieveUser/basic/index.vue'),
      },
      {
        path: '/achieveUser/mess/video',
        meta: { title: '视频信息管理' },
        component: () => import('../views/achieveUser/mess/video/index.vue'),
      },
      {
        path: '/achieveUser/mess/imgtxt',
        meta: { title: '图文信息管理' },
        component: () => import('../views/achieveUser/mess/imgtxt/index.vue'),
      },
      {
        path: '/achieveUser/mess/guest',
        meta: { title: '嘉宾访谈信息管理' },
        component: () => import('../views/achieveUser/mess/guest/index.vue'),
      },
      {
        path: '/achieveUser/mess/guest/detail',
        meta: { title: '嘉宾访谈详细信息' },
        component: () => import('../views/achieveUser/mess/guest/detail.vue'),
      },
      {
        path: '/achieveUser/mess/readshow',
        meta: { title: '项目路演信息管理' },
        component: () => import('../views/achieveUser/mess/readshow/index.vue'),
      },
      {
        path: '/achieveUser/mess/readshow/detail',
        meta: { title: '项目路演详细信息' },
        component: () => import('../views/achieveUser/mess/readshow/detail.vue'),
      },
      {
        path: '/achieveUser/apply',
        meta: { title: '展会申请管理' },
        component: () => import('../views/achieveUser/apply/index.vue'),
      },
      {
        path: '/achieveUser/apply/check',
        meta: { title: '展会审核管理' },
        component: () => import('../views/achieveUser/apply/check.vue'),
      },
      {
        path: '/achieveUser/trans',
        meta: { title: '交易记录管理' },
        component: () => import('../views/achieveUser/trans/index.vue'),
      },
      {
        path: '/achieveUser/census',
        meta: { title: '统计报表' },
        component: () => import('../views/achieveUser/census/index.vue'),
      },
      // 科技频道
      {
        path: '/channelUser/basic',
        meta: { title: '展会基本信息' },
        component: () => import('../views/channelUser/basic/index.vue'),
      },
      {
        path: '/channelUser/mess/video',
        meta: { title: '视频信息管理' },
        component: () => import('../views/channelUser/mess/video/index.vue'),
      },
      // 培训问诊
      {
        path: '/trainUser/basic',
        meta: { title: '展会基本信息' },
        component: () => import('../views/trainUser/basic/index.vue'),
      },
      {
        path: '/trainUser/mess/video',
        meta: { title: '视频信息管理' },
        component: () => import('../views/trainUser/mess/video/index.vue'),
      },
      {
        path: '/trainUser/user',
        meta: { title: '用户管理' },
        component: () => import('../views/trainUser/user/index.vue'),
      },
    ],
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = sessionStorage.getItem('token');
  if (to.path == '/adminCenter/homeIndex') {
    if (!token) {
      next('/login');
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
